<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="resultTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
      <detectionResult
        v-if="detectionVisible"
        ref="detectionResult"
      ></detectionResult>
    </basic-container>
  </div>
</template>

<script>
import { fetchListResult, updateIsUsed } from '@/api/quality/result'
import TableForm from './result-form'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table'
import detectionResult from './detection-result.vue'
import { remote } from '@/api/admin/dict'

export default {
  data() {
    return {
      ajaxFun: fetchListResult,
      addOrUpdateVisible: false,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            minWidth: '140',
            prop: 'systemNo',
            label: '系统编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'operationName',
            label: '产出工序',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'partBatchNo',
            label: 'SN号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.searchResult }
          },
          {
            minWidth: '140',
            prop: 'partNo',
            label: '零件编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'partName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'applyType',
            label: '检测类型',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: (row, column, cellValue) => {
              this.applyTypeOptions.forEach((obj) => {
                if (obj.value === cellValue) {
                  cellValue = obj.label
                }
              })
              return cellValue
            },
            optList: () => {
              return this.applyTypeOptions
            }
          },
          {
            minWidth: '140',
            prop: 'checkStatus',
            label: '检测状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: (row, column, cellValue) => {
              this.checkStatusOptions.forEach((obj) => {
                if (obj.value === cellValue) {
                  cellValue = obj.label
                }
              })
              return cellValue
            },
            optList: () => {
              return this.checkStatusOptions
            }
          },
          {
            minWidth: '140',
            prop: 'isQualified',
            label: '检测是否合格',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: (row, column, cellValue) => {
              var formatVal
              if (cellValue && cellValue == true) {
                formatVal = '<span>是</span>'
              } else if (cellValue == false) {
                formatVal = '<span style="color:red">否</span>'
              } else {
                formatVal = '<span></span>'
              }
              return formatVal
            },
            optList: () => {
              return this.booleanOptions
            }
          },
          {
            minWidth: '140',
            prop: 'isUsed',
            label: '是否允许使用',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: (row, column, cellValue) => {
              var formatVal
              if (cellValue && cellValue == true) {
                formatVal = '<span>是</span>'
              } else if (cellValue == false) {
                formatVal = '<span style="color:red">否</span>'
              } else {
                formatVal = '<span></span>'
              }
              return formatVal
            },
            optList: () => {
              return this.booleanOptions
            }
          },
          {
            minWidth: '140',
            prop: 'isSubmit',
            label: '检测汇报是否提交',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: (row, column, cellValue) => {
              var formatVal
              if (cellValue && cellValue == true) {
                formatVal = '<span>是</span>'
              } else if (cellValue == false) {
                formatVal = '<span">否</span>'
              } else {
                formatVal = '<span></span>'
              }
              return formatVal
            },
            optList: () => {
              return this.booleanOptions
            }
          },
          {
            minWidth: '140',
            prop: 'remark',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: [
          {
            text: '允许使用',
            type: 'primary',
            fun: this.updateIsUsedTrue
          },
          {
            text: '不允许使用',
            type: 'primary',
            fun: this.updateIsUsedFalse
          }
        ],
        operator: [
          {
            text: '检测汇报',
            type: 'text',
            size: 'small',
            fun: this.qualityReport
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      },
      booleanOptions: [
        { value: true, label: '是' },
        { value: false, label: '否' }
      ],
      checkStatusOptions: [
        { value: '01untested', label: '待检测' },
        { value: '02testing', label: '检测中' },
        { value: '03tested', label: '已检测' },
        { value: '04noTest', label: '不检测' }
      ],
      detectionVisible: false,
      applyTypeOptions: []
    }
  },
  components: {
    TableForm,
    ttable,
    detectionResult
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  created() {
    this.getReportTypeDict()
  },
  methods: {
    getReportTypeDict() {
      remote('apply_report_type').then((response) => {
        if (response.data.code === 0) {
          this.applyTypeOptions = response.data.data
        } else {
          this.applyTypeOptions = []
        }
      })
    },
    // 获取数据列表
    getData() {
      this.$refs.resultTable.getDataList()
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    updateIsUsedTrue() {
      this.updateIsUsed(true)
    },
    updateIsUsedFalse() {
      this.updateIsUsed(false)
    },
    updateIsUsed(isUsed) {
      if (this.multipleSelection && this.multipleSelection.length > 0) {
        this.$confirm(
          '是否标记为' + (isUsed ? '' : '不') + '允许使用',
          '提示',
          {
            confirmButtonText: '确定',
            cancelButtonText: '取消',
            closeOnClickModal: false,
            type: 'warning'
          }
        )
          .then(() => {
            const resultList = []
            this.multipleSelection.forEach((e) => {
              resultList.push(
                Object.assign({
                  id: e.id,
                  isUsed: isUsed
                })
              )
            })
            updateIsUsed(resultList).then((data) => {
              this.$message.success('使用状态更新成功')
              this.getData()
            })
          })
          .catch(() => {})
      } else {
        this.$message.warning('请选择检测结果')
      }
    },
    searchResult(row) {
      this.detectionVisible = true
      this.$nextTick(() => {
        this.$refs.detectionResult.init(row.id)
      })
    },
    qualityReport(row) {
      if (!row.reportNo) {
        this.$message.warning('没有检测汇报编号')
        return
      }
      // 先请求后端，查询出检测结果对应的所有检测汇报 reportNo
      this.$router.push('/quality/report/index')
      sessionStorage.setItem(
        'quality_report_index',
        row.reportNo ? row.reportNo : ''
      )
    }
  }
}
</script>
